@@ -2,7 +2,71 @@
 更新内容一览
 """
 
+"""
+2022/5/23
+control_version:0.6.0
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+本次修改更新较多，主要内容如下：
+1.增加了本地化语音
+2.增加了深度学习模块
+"""
 
+"""
+2022/5/23
+control_version:0.5.12
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+1、禁用了树莓派上使用本地化语音转文字
+2、优化了语音库的路径
+"""
+
+"""
+2022/5/22
+control_version:0.5.12
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+1、解决了树莓派上不能用语音的问题，树莓派上将使用mplayer来播放音频，win上使用playsound
+2、语音转文字中，删掉了文字中的中文数字转成阿拉伯数字时的print(numStr)
+"""
+        
+
+"""
+2022/5/20
+control_version:0.5.12
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+1、解决了路径问题。
+2、部署了本地化语音到语音库。
+3、显示窗口放大回640 x 320分辨率。
+"""
+
+"""
+2022/5/18
+control_version:0.5.12
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+改了所有库的注释以及参数的类型注解
+"""
+
+
+"""
+2022/5/11
+control_version:0.5.12
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+1.GPIO超声波返回值为两位小数的值，单位为cm
+2.改了语音的路径
+"""
+
+"""
+2022/5/11
+control_version:0.5.11
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+忘了修改了什么
+
+"""
 """
 2022/5/10
 control_version:0.5.10
