@@ -5,15 +5,15 @@
 """
 import warnings
 warnings.filterwarnings("ignore")
-from control.unique import  Number_Convert,playsound
+from control.unique import  Number_Convert,playsound,Yuyin_local
 from aip.speech import AipSpeech
-import os, re
+import os, re,json,threading,subprocess
 import wave
 import time
 import pyaudio
 import audioop
 import pygame
-# import base64
+import websocket
 import requests
 import urllib
 import sys
@@ -29,14 +29,16 @@ system_platform = sys.platform
 main_path = '/home/pi/class/'
 if 'win' in system_platform:
     # 获取当前文件的位置
-    file_path = os.getcwd()
-    main_path = file_path + '\\resources\\assets\\class\\'
-
+    file_path = os.path.join(os.getcwd().split('blockly-electron')[0],'blockly-electron')
+    if not os.path.exists(file_path):
+        if os.path.join(os.getcwd(),"resources"):
+            file_path = os.getcwd()
+    main_path = os.path.join(file_path + 'resources','assets','class').replace("\\","/")
 # 文本文件夹
-txt_path = main_path + 'txt\\'
+txt_path = os.path.join(main_path , 'txt/').replace("\\","/")
 
 # 音频文件夹
-audio_path = main_path + 'speech\\'
+audio_path = os.path.join(main_path , 'speech/').replace("\\","/")
 if not os.path.exists(audio_path):
     os.makedirs(audio_path)
 # # 开始时删除所有合成音频--Nonexxxxxxx.mp3/wav(固定格式)
@@ -75,10 +77,12 @@ class Yuyin():
         :param None
         """
         self.online = True # 这个参数是针对本地化语音转文字的，如果是True就是调用百度在线的，否则调用本地化的
-        for key,value in kwargs:
+        for key,value in kwargs.items():
             if key=="online":
-                self.online = value
-
+                self.online = value and ('win' in system_platform)
+        if 'win' not in system_platform:
+            print("树莓派上暂不支持本地模式，已为你切换成在线模式")
+            self.online=True
         #下面这三个是写死的
         self.app_id = app_id
         self.api_key = app_key
@@ -100,7 +104,11 @@ class Yuyin():
 
         self.NumConverter = Number_Convert() #把百度的语音转文字中的中文数字转化成阿拉伯数字
 
-    def change_vol_spd_gender_DUI(self, vol, spd, gender):
+
+
+
+
+    def change_vol_spd_gender_DUI(self, vol:int, spd:int, gender:str):
         """
         选择机器人播放时候的音量，播放速度以及声线（DUI版）
         网站：https://www.duiopen.com/docs/ct_cloud_TTS_Voice
@@ -117,7 +125,7 @@ class Yuyin():
         if not self.gender:
             raise KeyError("没有这个音色！")
 
-    def chat(self, my_text):
+    def chat(self, my_text:str):
         """
         在百度API获取聊天机器人，将聊天机器人的语句通过self.chat_ret返回
         :param my_text: 对机器人说的话，以str类型输入
@@ -128,7 +136,7 @@ class Yuyin():
         html = requests.get(url)
         self.chat_ret = html.json()["content"]
 
-    def downsampleWav(self, src, dst, inrate=48000, outrate=16000, inchannels=1, outchannels=1):
+    def downsampleWav(self, src:str, dst:str, inrate:int=48000, outrate:int=16000, inchannels:int=1, outchannels:int=1):
         """
         修改成语音文件格式到适合百度语音api
         :param src: 原来的录音文件
@@ -186,7 +194,7 @@ class Yuyin():
         return True
 
 
-    def my_record(self, TIME, file_name):
+    def my_record(self, TIME:int, file_name:str):
         """
         机器人录音，并将录音保存到.wav文件
         :param TIME: 录音时间长度
@@ -205,23 +213,26 @@ class Yuyin():
             RATE = 16000
 
         # 用时间戳和file_name作为文件名，时间戳保证文件的独特性
-        file_name = audio_path + str(file_name) +  '.wav'
-        stream = self.p.open(format=FORMAT,
-                             channels=CHANNELS,
-                             rate=RATE,
-                             input=True,
-                             frames_per_buffer=CHUNK)
-        print("开始录音,请说话,持续", TIME, "秒......")
-        frames = []
-        t = time.time()
-        while time.time() < t + TIME:
-            data = stream.read(CHUNK)
-            frames.append(data)
-        print("录音结束!")
-        # 停止音频流并关闭
-        stream.stop_stream()
-        stream.close()
-        # p.terminate()
+        try:
+            file_name = audio_path + str(file_name) +  '.wav'
+            stream = self.p.open(format=FORMAT,
+                                 channels=CHANNELS,
+                                 rate=RATE,
+                                 input=True,
+                                 frames_per_buffer=CHUNK)
+            print("开始录音,请说话,持续", TIME, "秒......")
+            frames = []
+            t = time.time()
+            while time.time() < t + TIME:
+                data = stream.read(CHUNK)
+                frames.append(data)
+            print("录音结束!")
+            # 停止音频流并关闭
+            stream.stop_stream()
+            stream.close()
+        except:
+            print("打开电脑音频失败，请重新尝试")
+            exit()
 
         # 打开WAV文件，以二进制写模式，并对WAV文件进行一系列操作
         wf = wave.open(file_name, 'wb')
@@ -240,16 +251,18 @@ class Yuyin():
 
             # 把file_name这个文件名给到修改后的文件
             os.rename(file_new_name, file_name)
+        else:
+            pass
 
-    def stt(self, filename):
+    def stt(self, filename:str):
         """
         语音识别返回识别结果字符串, 识别.wav文件中的语音,  中文普通话识别的免费次数为50000次。
         :param filename: 要进行转换的文本文件
         :return: None
         """
+        filename = audio_path + str(filename) + '.wav'
         if self.online:
-            # try:
-                filename = audio_path + str(filename) + '.wav'
+            try:
                 if os.path.exists(filename):
 
                     fp = open(filename, 'rb')
@@ -269,21 +282,26 @@ class Yuyin():
                         self.recordNumberList = [num[0] for num in numList]
                         return self.NumConverter.num_convert3(word)[0] # 返回识别结果值
                     else:
-                        return "语音识别失败:" + filename
-            # except:
-            #     return "没有连接网络"
+                        if 'win' not in system_platform:
+                            addStr = "是不是没装麦克风？文件名是:"
+                        else:
+                            addStr = "文件名是:"
+                        return "语音识别失败"+addStr + filename
+            except:
+                return "没有连接网络"
 
         else: #本地化语音转文字
-            res = os.popen(f"{audio_path}decoder_main.exe  --chunk_size -1  --wav_path {audio_path+'None'+'.wav'}  \
-                    --model_path {audio_path}final.zip --dict_path {audio_path}words.txt")
-            tempstream = res._stream
-            numList = self.NumConverter.num_convert3(tempstream.buffer.read().decode(encoding='utf-8', errors='ignore').split(' ')[1].split('\r\n')[0])
-            word = [num[0] for num in numList]
-            self.recordNumberList = word[1]
-            return word[0]
+            local_yuyinPath = os.path.join(audio_path, "local_yuyin") #本地化语音模型存放地点
+            preWorkDir = os.getcwd() #将目前工作路径记录下来
+            os.chdir(local_yuyinPath) #切换工作路径到本地化语音模型路径
+            local_yuyin = Yuyin_local(record_time_s=-1,local_yuyinPath=local_yuyinPath,asyn=False,filename=filename)
+            # local_yuyin.filename = filename
+            local_yuyin.run()
+            os.chdir(preWorkDir) #将工作路径切换回去
+            return local_yuyin.total_sentance
 
 
-    def tts(self, txt,filename):
+    def tts(self, txt:str,filename:str):
         """
         将文本转为音频  语音合成免费额度只有5000次（未认证），认证之后有50000次，在180天内有效
         :param txt: 转语音的文本
@@ -315,9 +333,26 @@ class Yuyin():
                 with open(file, 'wb') as f:
                     f.write(result)
 
+    def asyn_speech2text(self,record_time_s:int):
+        '''
+        一边说话一边识别
+        :return:
+        '''
+        if self.online:
+            self.my_record(record_time_s,"asy_yuyin")
+            return self.stt("asy_yuyin")
+        else:
+            #下面涉及切换工作路径的原因可以参考上面stt的注释
+            local_yuyinPath = os.path.join(audio_path, "local_yuyin")
+            preWorkDir = os.getcwd()
+            os.chdir(local_yuyinPath)
+            local_yuyin = Yuyin_local(record_time_s,local_yuyinPath=local_yuyinPath)
+            local_yuyin.run()
+            os.chdir(preWorkDir)
+            return local_yuyin.total_sentance
 
 
-    def play_bufen(self, filename, play_time):
+    def play_bufen(self, filename:str, play_time:int):
         """
         用于加载音频文件并播放
         :param filename: 音频文件
@@ -330,7 +365,7 @@ class Yuyin():
         time.sleep(play_time)
         pygame.mixer.music.stop()
 
-    def play_music(self, filename):
+    def play_music(self, filename:str):
 
         """
         播放音频及音乐,只能播放.mp3文件
@@ -351,13 +386,20 @@ class Yuyin():
             raise FileNotFoundError("找不到该音频文件，是不是还没录制呢？")
         precwd = os.getcwd()
         os.chdir(audio_path)
-        playsound(filename)
+        if 'win' in system_platform:
+            playsound(filename)
+        else:
+            result = os.system("mplayer "+filename)
+            if result != 0:
+                print("这台树莓派上好像没有装mplayer(用于播放音频)，下面开始安装...")
+                os.system("sudo apt install mplayer")
+                os.system("mplayer "+filename)
         os.chdir(precwd)
 
 
 
 
-    def play_txt(self, txt):
+    def play_txt(self, txt:str):
         '''
         将文本转换为语音并播放
         :param txt: 需要转换为音频的文本
